@@ -20,3 +20,5 @@
 
 require_relative 'event/spawn'
 require_relative 'event/failure'
+require_relative 'event/metric'
+require_relative 'event/progress'
